@@ -59,7 +59,7 @@ class Node:
             self.process = Popen(command)
 
         else:
-            command = "exec geth --identity {0}  -cache=1024 --syncmode \"light\" --minerthreads 2 --http --http.port {1} --http.corsdomain \"*\" --datadir \"{2}\" " \
+            command = "exec geth --identity {0}  -cache=1024 --syncmode \"light\" --http --http.port {1} --http.corsdomain \"*\" --datadir \"{2}\" " \
                       "--port " \
                       "{3} --nodiscover --http.api  \"eth,net,web3,personal,miner,admin\" --networkid {4} --nat " \
                       "\"any\" --ipcdisable --allow-insecure-unlock ".format(str(self.name), str(self.rpcport),
